@@ -339,7 +339,7 @@ char	*parv[];
 			   get_client_name(acptr, TRUE), host);
 		return exit_client(acptr, acptr, acptr, "Server Exists");
 	    }
-	if ((acptr = find_client(host, NULL)))
+	if ((acptr = find_client(host, NULL)) && acptr != cptr)
 	    {
 		/*
 		** Server trying to use the same name as a person. Would
